@@ -26,27 +26,25 @@
 ##' \code{metric.select.thresh} to exclude single models based on their evaluation scores 
 ##' (for ensemble methods like probability weighted mean or committee averaging). Must be among  
 ##' \code{all} (same evaluation metrics than those of \code{bm.mod}), \code{user.defined} 
-##' (and defined through \code{metric.select.table}) or \code{ROC}, \code{TSS}, \code{KAPPA}, 
-##' \code{ACCURACY}, \code{BIAS}, \code{POD}, \code{FAR}, \code{POFD}, \code{SR}, \code{CSI}, 
-##' \code{ETS}, \code{HK}, \code{HSS}, \code{OR}, \code{ORSS}
+##' (and defined through \code{metric.select.table}) or \code{POD}, \code{FAR}, \code{POFD}, 
+##' \code{SR}, \code{ACCURACY}, \code{BIAS}, \code{ROC}, \code{TSS}, \code{KAPPA}, \code{OR}, 
+##' \code{ORSS}, \code{CSI}, \code{ETS}, \code{BOYCE}, \code{MPA}
 ##' @param metric.select.thresh (\emph{optional, default} \code{NULL}) \cr 
 ##' A \code{vector} of \code{numeric} values corresponding to the minimum scores (one for each 
 ##' \code{metric.select}) below which single models will be excluded from the ensemble model 
 ##' building
-##' @param metric.select.table (\emph{optional, default} \code{NULL}) \cr If
-##'   \code{metric.select = 'user.defined'}, a \code{data.frame} containing
-##'   evaluation scores calculated for each single models and that will be
-##'   compared to \code{metric.select.thresh} values to exclude some of them
-##'   from the ensemble model building, with \code{metric.select} rownames, and
-##'   \code{models.chosen} colnames
-##' @param metric.select.dataset (\emph{optional, default} \code{'validation'}
-##'   \emph{if possible}). A character determining which dataset should be used
-##'   to filter and/or weigh the ensemble models should be among 'evaluation',
-##'   'validation' or 'calibration'.
+##' @param metric.select.table (\emph{optional, default} \code{NULL}) \cr If 
+##' \code{metric.select = 'user.defined'}, a \code{data.frame} containing evaluation scores 
+##' calculated for each single models and that will be compared to \code{metric.select.thresh} 
+##' values to exclude some of them from the ensemble model building, with \code{metric.select} 
+##' rownames, and \code{models.chosen} colnames
+##' @param metric.select.dataset (\emph{optional, default} \code{'validation'} 
+##' \emph{if possible}). A character determining which dataset should be used to filter and/or 
+##' weigh the ensemble models should be among 'evaluation', 'validation' or 'calibration'.
 ##' @param metric.eval a \code{vector} containing evaluation metric names to be used, must 
-##' be among \code{ROC}, \code{TSS}, \code{KAPPA}, \code{ACCURACY}, \code{BIAS}, \code{POD}, 
-##' \code{FAR}, \code{POFD}, \code{SR}, \code{CSI}, \code{ETS}, \code{HK}, \code{HSS}, \code{OR}, 
-##' \code{ORSS}
+##' be among  \code{POD}, \code{FAR}, \code{POFD}, \code{SR}, \code{ACCURACY}, \code{BIAS}, 
+##' \code{ROC}, \code{TSS}, \code{KAPPA}, \code{OR}, \code{ORSS}, \code{CSI}, \code{ETS}, 
+##' \code{BOYCE}, \code{MPA}
 ##' @param var.import (\emph{optional, default} \code{NULL}) \cr 
 ##' An \code{integer} corresponding to the number of permutations to be done for each variable to 
 ##' estimate variable importance
@@ -666,7 +664,8 @@ BIOMOD_EnsembleModeling <- function(bm.mod,
                     if (all(!eval.lines)) { eval.lines <- !eval.lines }
                   }
                 } else {
-                  eval.lines <- rep(TRUE, length(pred.bm))
+                  eval.lines <- rep(FALSE, length(obs))
+                  eval.lines[as.numeric(rownames(pred.newdata))] <- TRUE
                 }
                 
                 
@@ -960,9 +959,9 @@ BIOMOD_EnsembleModeling <- function(bm.mod,
   
   ## 7. Check metric.eval -----------------------------------------------------
   metric.eval <- unique(metric.eval)
-  avail.eval.meth.list <- c('TSS', 'KAPPA', 'ACCURACY', 'BIAS', 'POD', 'FAR', 'POFD'
-                            , 'SR', 'CSI', 'ETS', 'HK', 'HSS', 'OR', 'ORSS', 'ROC'
-                            , 'BOYCE', 'MPA')
+  avail.eval.meth.list <- c('POD', 'FAR', 'POFD', 'SR', 'ACCURACY', 'BIAS'
+                            , 'ROC', 'TSS', 'KAPPA', 'OR', 'ORSS', 'CSI'
+                            , 'ETS', 'BOYCE', 'MPA')
   .fun_testIfIn(TRUE, "metric.eval", metric.eval, avail.eval.meth.list)
   
   ## 8. Check selected EM algo ------------------------------------------------
