@@ -9,40 +9,6 @@
 #'
 NULL
 
-#' @title BIOMOD_ConvertOldRun
-#' @description Deprecated function used in \pkg{biomod2} 3.5.1 to convert
-#' results from older version into the current version
-#' @param ... Additional arguments
-#' 
-#' @name BIOMOD_ConvertOldRun-deprecated
-#' @usage BIOMOD_ConvertOldRun(...)
-#' @seealso \code{\link{biomod2-deprecated}}
-#' @keywords internal
-NULL
-#' @rdname biomod2-deprecated
-#' @section \code{BIOMOD_ConvertOldRun}:
-#' \code{BIOMOD_ConvertOldRun} was removed in \pkg{biomod2} version 4.0.
-#'
-#' @export
-BIOMOD_ConvertOldRun <- function(...) { .Deprecated() }
-
-#' @title BIOMOD_cv
-#' @description Deprecated function name for
-#'   \code{\link{BIOMOD_CrossValidation}}
-#' @param ... Additional arguments
-#'
-#' @name BIOMOD_cv-deprecated
-#' @usage BIOMOD_cv(...)
-#' @seealso \code{\link{biomod2-deprecated}}
-#' @keywords internal
-NULL
-#' @rdname biomod2-deprecated
-#' @section \code{BIOMOD_cv}:
-#' For \code{BIOMOD_cv} use \code{\link{BIOMOD_CrossValidation}}.
-#'
-#' @export
-BIOMOD_cv <- function(...) { .Deprecated("BIOMOD_CrossValidation") }
-
 #' @title BIOMOD_CrossValidation
 #' @description Deprecated function name for
 #'   \code{\link{bm_CrossValidation}}
@@ -60,40 +26,39 @@ NULL
 #' @export
 BIOMOD_CrossValidation <- function(...) { .Deprecated("bm_CrossValidation") }
 
-#' @title BIOMOD_presenceonly
+#' @title BIOMOD_PresenceOnly
 #' @description Deprecated function name for
-#'   \code{\link{BIOMOD_PresenceOnly}}
+#'   \code{\link{bm_FindOptimStat}}
 #' @param ... Additional arguments
 #'
-#' @name BIOMOD_presenceonly-deprecated
-#' @usage BIOMOD_presenceonly(...)
+#' @name BIOMOD_PresenceOnly-deprecated
+#' @usage BIOMOD_PresenceOnly(...)
 #' @seealso \code{\link{biomod2-deprecated}}
 #' @keywords internal
 NULL
 #' @rdname biomod2-deprecated
-#' @section \code{BIOMOD_presenceonly}:
-#' For \code{BIOMOD_presenceonly} use \code{\link{BIOMOD_PresenceOnly}}.
+#' @section \code{BIOMOD_PresenceOnly}:
+#' For \code{BIOMOD_PresenceOnly} use \code{\link{bm_FindOptimStat}}.
 #'
 #' @export
-BIOMOD_presenceonly <- function(...) { .Deprecated("BIOMOD_PresenceOnly") }
+BIOMOD_PresenceOnly <- function(...) { .Deprecated("bm_FindOptimStat") }
 
-
-#' @title BIOMOD_tuning
+#' @title BIOMOD_Tuning
 #' @description Deprecated function name for
-#'   \code{\link{BIOMOD_Tuning}}
+#'   \code{\link{bm_Tuning}}
 #' @param ... Additional arguments
 #'
 #' @name BIOMOD_tuning-deprecated
-#' @usage BIOMOD_tuning(...)
+#' @usage BIOMOD_Tuning(...)
 #' @seealso \code{\link{biomod2-deprecated}}
 #' @keywords internal
 NULL
 #' @rdname biomod2-deprecated
-#' @section \code{BIOMOD_tuning}:
-#' For \code{BIOMOD_tuning} use \code{\link{BIOMOD_Tuning}}.
+#' @section \code{BIOMOD_Tuning}:
+#' For \code{BIOMOD_Tuning} use \code{\link{bm_Tuning}}.
 #'
 #' @export
-BIOMOD_tuning <- function(...) { .Deprecated("BIOMOD_Tuning") }
+BIOMOD_Tuning <- function(...) { .Deprecated("bm_Tuning") }
 
 #' @title BinaryTransformation
 #' @description Deprecated function name for
@@ -112,7 +77,6 @@ NULL
 #' @export
 BinaryTransformation <- function(...) { .Deprecated("bm_BinaryTransformation") }
 
-
 #' @title calculate.stat
 #' @description Deprecated function name for
 #'   \code{\link{bm_CalculateStat}}
@@ -130,44 +94,6 @@ NULL
 #' @export
 calculate.stat <- function(...) { .Deprecated("bm_CalculateStat") }
 
-
-#' @title CustomIndexMaker
-#' @description Deprecated function used in \pkg{biomod2} 3.5.1 to replace
-#'   default html index file by a custom one if defined
-#' @param ... Additional arguments
-#'
-#' @name CustomIndexMaker-deprecated
-#' @usage CustomIndexMaker(...)
-#' @seealso \code{\link{CustomIndexMaker-deprecated}}
-#' @keywords internal
-NULL
-#' @rdname biomod2-deprecated
-#' @section \code{CustomIndexMaker}:
-#' \code{CustomIndexMaker} was removed in \pkg{biomod2} version 4.0.
-#'
-#' @export
-CustomIndexMaker <- function(...) { .Deprecated() }
-
-
-
-#' @title FilteringTransformation
-#' @description Deprecated function name for
-#'   \code{\link{BinaryTransformation}}
-#' @param ... Additional arguments
-#'
-#' @name FilteringTransformation-deprecated
-#' @usage FilteringTransformation(...)
-#' @seealso \code{\link{biomod2-deprecated}}
-#' @keywords internal
-NULL
-#' @rdname biomod2-deprecated
-#' @section \code{FilteringTransformation}:
-#' For \code{FilteringTransformation} use \code{\link{BinaryTransformation}}.
-#'
-#' @export
-FilteringTransformation <- function(...) { .Deprecated("BinaryTransformation") }
-
-
 #' @title Find.Optim.Stat
 #' @description Deprecated function name for
 #'   \code{\link{bm_FindOptimStat}}
@@ -236,23 +162,6 @@ NULL
 #' @export
 models_scores_graph <- function(...) { .Deprecated("bm_PlotEvalMean") }
 
-#' @title Print_Default_ModelingOptions
-#' @description Deprecated function name for
-#'   \code{\link{bm_DefaultModelingOptions}}
-#' @param ... Additional arguments
-#'
-#' @name Print_Default_ModelingOptions-deprecated
-#' @usage Print_Default_ModelingOptions(...)
-#' @seealso \code{\link{biomod2-deprecated}}
-#' @keywords internal
-NULL
-#' @rdname biomod2-deprecated
-#' @section \code{Print_Default_ModelingOptions}:
-#' For \code{Print_Default_ModelingOptions} use \code{\link{bm_DefaultModelingOptions}}.
-#'
-#' @export
-Print_Default_ModelingOptions <- function(...) { .Deprecated("bm_DefaultModelingOptions") }
-
 #' @title ProbDensFunc
 #' @description Deprecated function name for
 #'   \code{\link{bm_PlotRangeSize}}
@@ -270,24 +179,6 @@ NULL
 #' @export
 ProbDensFunc <- function(...) { .Deprecated("bm_PlotRangeSize") }
 
-
-#' @title response.plot
-#' @description Deprecated function name for
-#'   \code{\link{bm_PlotResponseCurves}}
-#' @param ... Additional arguments
-#'
-#' @name response.plot-deprecated
-#' @usage response.plot(...)
-#' @seealso \code{\link{biomod2-deprecated}}
-#' @keywords internal
-NULL
-#' @rdname biomod2-deprecated
-#' @section \code{response.plot}:
-#' For \code{response.plot} use \code{\link{bm_PlotResponseCurves}}.
-#'
-#' @export
-response.plot <- function(...) { .Deprecated("bm_PlotResponseCurves") }
-
 #' @title response.plot2
 #' @description Deprecated function name for
 #'   \code{\link{bm_PlotResponseCurves}}
@@ -339,24 +230,6 @@ NULL
 #' @export
 sre <- function(...) { .Deprecated("bm_SRE") }
 
-#' @title .transform.outputs.array
-#' @description Deprecated function used in \pkg{biomod2} 3.5.1 to transform
-#' outputs into array
-#' @param ... Additional arguments
-#'
-#' @name .transform.outputs.array-deprecated
-#' @usage .transform.outputs.array(...)
-#' @seealso \code{\link{biomod2-deprecated}}
-#' @keywords internal
-NULL
-#' @rdname biomod2-deprecated
-#' @section \code{.transform.outputs.array}:
-#' \code{.transform.outputs.array} was removed in \pkg{biomod2} version 4.0.
-#'
-#' @export
-.transform.outputs.array <- function(...) { .Deprecated() }
-
-
 #' @title .transform.outputs.list
 #' @description Deprecated function name for
 #'   \code{.transform_outputs_list}
@@ -374,24 +247,6 @@ NULL
 #' @export
 .transform.outputs.list <- function(...) { .Deprecated(".transform_outputs_list") }
 
-#' @title update_objects
-#' @description Deprecated function used in \pkg{biomod2} 3.5.1 to update
-#'   objects construct with a old version of biomod2 to a current one
-#' @param ... Additional arguments
-#'
-#' @name update_objects-deprecated
-#' @usage update_objects(...)
-#' @seealso \code{\link{biomod2-deprecated}}
-#' @keywords internal
-NULL
-#' @rdname biomod2-deprecated
-#' @section \code{update_objects}:
-#' \code{update_objects} was removed in \pkg{biomod2} version 4.0.
-#'
-#' @export
-update_objects <- function(...) { .Deprecated() }
-
-
 #' @title variables_importance
 #' @description Deprecated function name for
 #'   \code{\link{bm_VariablesImportance}}
@@ -409,12 +264,3 @@ NULL
 #' @export
 variables_importance <- function(...) { .Deprecated("bm_VariablesImportance") }
 
-
-# DF_to_ARRAY
-# evaluate
-# full_suffling
-# level.plot
-# multiple.plot
-# randomise_data
-# SampleMat2
-# zzz_bm
\ No newline at end of file
