@@ -1,4 +1,4 @@
-# bm_CrossValidation ------------------------------------------------------
+###################################################################################################
 ##' @name bm_CrossValidation
 ##' @author Frank Breiner, Maya Gueguen
 ##' 
@@ -8,14 +8,13 @@
 ##' according to 6 different methods : \code{random}, \code{kfold}, \code{block}, \code{strat}, 
 ##' \code{env} or \code{user.defined} (see Details).
 ##' 
-##' @param bm.format a \code{\link{BIOMOD.formated.data-class}} or 
-##' \code{\link{BIOMOD.formated.data.PA-class}} object returned by the 
-##' \code{\link{BIOMOD_FormatingData}} function
+##' @param bm.format a \code{\link{BIOMOD.formated.data}} or \code{\link{BIOMOD.formated.data.PA}} 
+##' object returned by the \code{\link{BIOMOD_FormatingData}} function
 ##' @param strategy a \code{character} corresponding to the cross-validation selection strategy, 
 ##' must be among \code{random}, \code{kfold}, \code{block}, \code{strat}, \code{env} or 
 ##' \code{user.defined}
-##' @param \ldots (\emph{optional, one or several of the following arguments depending on the selected 
-##' method}) 
+##' @param \ldots (\emph{optional, one or several of the following arguments depending on the 
+##' selected method}) 
 ##' 
 ##' @param nb.rep (\emph{optional, default} \code{0}) \cr
 ##' If \code{strategy = 'random'} or \code{strategy = 'kfold'}, an \code{integer} corresponding 
@@ -26,18 +25,17 @@
 ##' @param k (\emph{optional, default} \code{0}) \cr
 ##' If \code{strategy = 'kfold'} or \code{strategy = 'strat'} or \code{strategy = 'env'}, an 
 ##' \code{integer} corresponding to the number of partitions 
-##' @param balance (\emph{optional, default} \code{'presences'}) \cr If
-##'   \code{strategy = 'strat'} or \code{strategy = 'env'}, a \code{character}
-##'   corresponding to how data will be balanced between partitions, must be
-##'   either \code{presences} or \code{absence}
-##' @param env.var (\emph{optional}) \cr If \code{strategy = 'env'}, a
-##'   \code{character} corresponding to the environmental variables used to
-##'   build the partition. \code{k} partitions will be built for each
-##'   environmental variables. By default the function uses all environmental
-##'   variables available.
-##' @param strat (\emph{optional, default} \code{'both'}) \cr If \code{strategy
-##'   = 'env'}, a \code{character} corresponding to how data will partitioned
-##'   along gradient, must be among \code{x}, \code{y}, \code{both}
+##' @param balance (\emph{optional, default} \code{'presences'}) \cr 
+##' If \code{strategy = 'strat'} or \code{strategy = 'env'}, a \code{character} corresponding 
+##' to how data will be balanced between partitions, must be either \code{presences} or 
+##' \code{absence}
+##' @param env.var (\emph{optional}) \cr 
+##' If \code{strategy = 'env'}, a \code{character} corresponding to the environmental variables 
+##' used to build the partition. \code{k} partitions will be built for each environmental 
+##' variables. \emph{By default the function uses all environmental variables available.}
+##' @param strat (\emph{optional, default} \code{'both'}) \cr 
+##' If \code{strategy = 'env'}, a \code{character} corresponding to how data will partitioned 
+##' along gradient, must be among \code{x}, \code{y}, \code{both}
 ##' @param user.table (\emph{optional, default} \code{NULL}) \cr
 ##' If \code{strategy = 'user.defined'}, a \code{matrix} or \code{data.frame} defining for each 
 ##' repetition (in columns) which observation lines should be used for models calibration 
@@ -81,36 +79,44 @@
 ##' \bold{Concerning cross-validation strategies :}
 ##' 
 ##' \describe{
-##'   \item{random}{Most simple method to calibrate and validate a model is to split the original dataset in two 
-##' datasets : one to calibrate the model and the other one to validate it. The splitting can be 
-##' repeated \code{nb.rep} times.}
-##'   \item{k-fold}{The k-fold method splits the original dataset in \code{k} datasets of equal sizes : each part 
-##' is used successively as the validation dataset while the other \code{k-1} parts are used for 
-##' the calibration, leading to \code{k} calibration/validation ensembles. This multiple splitting 
-##' can be repeated \code{nb.rep} times.}
-##'   \item{block}{It may be used to test for model overfitting and to assess transferability in geographic space.
-##' \code{block} stratification was described in \emph{Muscarella et al. 2014} (see References). 
-##' Four bins of equal size are partitioned (bottom-left, bottom-right, top-left and top-right).}
-##'   \item{stratified}{It may be used to test for model overfitting and to assess transferability in geographic space.
-##' \code{x} and \code{y} stratification was described in \emph{Wenger and Olden 2012} (see 
-##' References). \code{y} stratification uses \code{k} partitions along the y-gradient, \code{x} 
-##' stratification does the same for the x-gradient. \code{both} returns \code{2k} partitions: \code{k} partitions stratified along the x-gradient and \code{k} partitions stratified along the y-gradient.}
-##'   \item{environmental}{It may be used to test for model overfitting and to assess transferability in environmental space. It returns \code{k} partitions for each variable given in \code{env.var}.}
-##'   \item{user-defined}{Allow the user to give its own crossvalidation table. For a presence-absence dataset, column names must be formatted as: \code{_allData_RUNx} with \code{x} an integer. For a presence-only dataset for which several pseudo-absence dataset were generated, column names must be formatted as: \code{_PAx_RUNy} with \code{x} an integer and \code{PAx} an existing pseudo-absence dataset and \code{y} an integer \cr \cr}
+##'   \item{random}{Most simple method to calibrate and validate a model is to split the original 
+##'   dataset in two datasets : one to calibrate the model and the other one to validate it. The 
+##'   splitting can be repeated \code{nb.rep} times.}
+##'   \item{k-fold}{The k-fold method splits the original dataset in \code{k} datasets of equal 
+##'   sizes : each part is used successively as the validation dataset while the other \code{k-1} 
+##'   parts are used for the calibration, leading to \code{k} calibration/validation ensembles. 
+##'   This multiple splitting can be repeated \code{nb.rep} times.}
+##'   \item{block}{It may be used to test for model overfitting and to assess transferability in 
+##'   geographic space. \code{block} stratification was described in \emph{Muscarella et al. 2014} 
+##'   (see References). Four bins of equal size are partitioned (bottom-left, bottom-right, 
+##'   top-left and top-right).}
+##'   \item{stratified}{It may be used to test for model overfitting and to assess transferability 
+##'   in geographic space. \code{x} and \code{y} stratification was described in \emph{Wenger and 
+##'   Olden 2012} (see References). \code{y} stratification uses \code{k} partitions along the 
+##'   y-gradient, \code{x} stratification does the same for the x-gradient. \code{both} returns 
+##'   \code{2k} partitions: \code{k} partitions stratified along the x-gradient and \code{k} 
+##'   partitions stratified along the y-gradient.}
+##'   \item{environmental}{It may be used to test for model overfitting and to assess 
+##'   transferability in environmental space. It returns \code{k} partitions for each variable 
+##'   given in \code{env.var}.}
+##'   \item{user-defined}{Allow the user to give its own crossvalidation table. For a 
+##'   presence-absence dataset, column names must be formatted as: \code{_allData_RUNx} with 
+##'   \code{x} an integer. For a presence-only dataset for which several pseudo-absence dataset 
+##'   were generated, column names must be formatted as: \code{_PAx_RUNy} with \code{x} an 
+##'   integer and \code{PAx} an existing pseudo-absence dataset and \code{y} an integer \cr \cr}
 ##' }
 ##' 
 ##' 
 ##' \bold{Concerning balance parameter :}
 ##' 
-##' If \code{balance = 'presences'}, presences are divided (balanced) equally
-##' over the partitions (e.g. \emph{Fig. 1b in Muscarelly et al. 2014}).
-##' Absences or pseudo-absences will however be unbalanced over the partitions
-##' especially if the presences are clumped on an edge of the study area.
+##' If \code{balance = 'presences'}, presences are divided (balanced) equally over the partitions 
+##' (e.g. \emph{Fig. 1b in Muscarelly et al. 2014}). 
+##' Absences or pseudo-absences will however be unbalanced over the partitions especially if the 
+##' presences are clumped on an edge of the study area.
 ##' 
-##' If \code{balance = 'absences'}, absences (resp. pseudo-absences or
-##' background) are divided (balanced) as equally as possible between the
-##' partitions (geographical balanced bins given
-##' that absences are spread over the study area equally, approach similar to \emph{Fig. 1 in
+##' If \code{balance = 'absences'}, absences (resp. pseudo-absences or background) are divided 
+##' (balanced) as equally as possible between the partitions (geographical balanced bins given 
+##' that absences are spread over the study area equally, approach similar to \emph{Fig. 1 in 
 ##' Wenger et Olden 2012}). Presences will however be unbalanced over the partitions especially
 ##' if the presences are clumped on an edge of the study area.
 ##' 
@@ -211,6 +217,8 @@
 ##' apply(cv.e, 2, table)
 ##' 
 ##' 
+##' @importFrom foreach foreach %do%
+##' 
 ##' @export
 ##' 
 ##' 
@@ -477,16 +485,20 @@ setMethod('bm_CrossValidation_user.defined', signature(bm.format = "BIOMOD.forma
 setMethod('bm_CrossValidation_user.defined', signature(bm.format = "BIOMOD.formated.data.PA"),
           function(bm.format, user.table) {
             cat("\n   > User defined cross-validation selection")
-            .check_calib.lines_names(user.table, 
-                                     expected_PA.names = colnames(bm.format@PA.table))
+            nb_PA <- ncol(bm.format@PA.table)
+            names_to_remove <- c("_allData_allRun", paste0("_PA", 1:nb_PA, "_allRun")) #We suppose that if they are in the format it should be fine
+            table_to_test <- user.table[,!(colnames(user.table) %in% names_to_remove)]
             
+            expected_PA.names <- colnames(bm.format@PA.table)
+            .check_calib.lines_names(table_to_test, expected_PA.names = expected_PA.names)
+            
+            PA.table <- cbind(bm.format@PA.table, "allData" = TRUE) #just to pass the check
             calib.lines <-
-              foreach(this.colnames = colnames(user.table),
-                      .combine = "cbind") %do% {
+              foreach(this.colnames = colnames(user.table), .combine = "cbind") %do% {
                         this.pa = strsplit(this.colnames, split = "_")[[1]][2]
                         calib.pa <- user.table[,this.colnames, drop = FALSE]
-                        which.not.pa <- which(bm.format@PA.table[, this.pa] == FALSE |
-                                                is.na(bm.format@PA.table[, this.pa]))
+                        which.not.pa <- which(PA.table[, this.pa] == FALSE |
+                                                is.na(PA.table[, this.pa]))
                         if(length(which.not.pa) > 0){
                           calib.pa[which.not.pa, ] <- NA
                         }
